@@ -9,6 +9,8 @@ import paraselene.tag.form.*;
 import paraselene.tag.list.*;
 import paraselene.tag.table.*;
 import paraselene.dyna.*;
+import paraselene.css.*;
+import paraselene.ui.*;
 
 /**
  * サイトページ基底クラス。
