@@ -1370,5 +1370,28 @@ public abstract class Page implements Serializable {
 	public void setPageServerInformation( PageServerInformation psi ) {
 		server_info = psi;
 	}
+
+	private transient ArrayList<Cookie>	cookie = new ArrayList<Cookie>();
+
+	/**
+	 * クッキーの追加。クライアントに返したいクッキーを設定します。<br>
+	 * このインスタンスが output からリターンされた時にクッキーを返します。
+	 * <br>クライアントへクッキーを返すとクッキーはクリアされます。
+	 * @param c クッキー。
+	 */
+	public void addCookie( Cookie c ) {
+		cookie.add( c );
+	}
+
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void setResponse( HttpServletResponse res ) {
+		int	cnt = cookie.size();
+		for ( int i = 0; i < cnt; i++ ) {
+			res.addCookie( cookie.get( i ) );
+		}
+		cookie = new ArrayList<Cookie>();
+	}
 }
 
