@@ -1,4 +1,4 @@
-// Paraselene2 2.1.2 (http://paraselene.sourceforge.jp/) generated this source file.
+// Paraselene2 2.1.3 (http://paraselene.sourceforge.jp/) generated this source file.
 /*
  * Paraselene
  * Copyright (c) 2009, 2010  Akira Terasaki
@@ -772,8 +772,132 @@ public enum WebColor implements Valuable {
 	/**
 	 * TRANSPARENT
 	 */
-	TRANSPARENT( 0xffffffff, 0xffffffff, 0xffffffff );
-	private static final long serialVersionUID = 1261820294044L;
+	TRANSPARENT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * INHERIT
+	 */
+	INHERIT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * CURRENTCOLOR
+	 */
+	CURRENTCOLOR( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * ACTIVEBORDER
+	 */
+	ACTIVEBORDER( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * ACTIVECAPTION
+	 */
+	ACTIVECAPTION( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * APPWORKSPACE
+	 */
+	APPWORKSPACE( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * BACKGROUND
+	 */
+	BACKGROUND( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * BUTTONFACE
+	 */
+	BUTTONFACE( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * BUTTONHIGHLIGHT
+	 */
+	BUTTONHIGHLIGHT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * BUTTONSHADOW
+	 */
+	BUTTONSHADOW( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * BUTTONTEXT
+	 */
+	BUTTONTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * CAPTIONTEXT
+	 */
+	CAPTIONTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * GRAYTEXT
+	 */
+	GRAYTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * HIGHLIGHT
+	 */
+	HIGHLIGHT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * HIGHLIGHTTEXT
+	 */
+	HIGHLIGHTTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * INACTIVEBORDER
+	 */
+	INACTIVEBORDER( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * INACTIVECAPTION
+	 */
+	INACTIVECAPTION( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * INACTIVECAPTIONTEXT
+	 */
+	INACTIVECAPTIONTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * INFOBACKGROUND
+	 */
+	INFOBACKGROUND( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * INFOTEXT
+	 */
+	INFOTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * MENU
+	 */
+	MENU( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * MENUTEXT
+	 */
+	MENUTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * SCROLLBAR
+	 */
+	SCROLLBAR( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * THREEDDARKSHADOW
+	 */
+	THREEDDARKSHADOW( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * THREEDFACE
+	 */
+	THREEDFACE( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * THREEDHIGHLIGHT
+	 */
+	THREEDHIGHLIGHT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * THREEDLIGHTSHADOW
+	 */
+	THREEDLIGHTSHADOW( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * THREEDSHADOW
+	 */
+	THREEDSHADOW( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * WINDOW
+	 */
+	WINDOW( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * WINDOWFRAME
+	 */
+	WINDOWFRAME( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * WINDOWTEXT
+	 */
+	WINDOWTEXT( 0xffffffff, 0xffffffff, 0xffffffff ),
+	/**
+	 * FLAVOR
+	 */
+	FLAVOR( 0xffffffff, 0xffffffff, 0xffffffff );
+	private static final long serialVersionUID = 1263646533488L;
 	int red, green, blue;
 	private WebColor( int r, int g, int b ) {
 		red = r;green = g;blue= b;
