@@ -19,7 +19,7 @@ public class Close implements Serializable {
 	private Close(){}
 	public Close( Page page ) {
 		page_id = page.getUniqueKey();
-		modal = page.getPopupType() == Popup.Type.MODAL;
+		modal = Popup.Type.isMode( page );
 	}
 }
 
