@@ -57,7 +57,7 @@ public class Closure extends Forward implements AjaxForward {
 	/**
 	 * コンストラクタ。
 	 * 履歴上で、直前にスタックされているページで output を処理します。<br>
-	 * Daemon からこのコンストラクタを指定しても何も起きません。<br>
+	 * Daemon からこのコンストラクタを指定するとクラッシュします。<br>
 	 * セッションは維持されます。
 	 */
 	public Closure() {
@@ -67,7 +67,8 @@ public class Closure extends Forward implements AjaxForward {
 
 	/**
 	 * コンストラクタ。
-	 * @param page ポップアップ。これがポップアップでなければ動作は不定です。
+	 * @param page ポップアップ。
+	 * これがポップアップでなければ動作は不定です。
 	 */
 	public Closure( Page page ) {
 		super( page.getParentPage().getID() );
@@ -95,5 +96,14 @@ public class Closure extends Forward implements AjaxForward {
 		Option.trace( "new CloseOutput <- %s", this );
 		return new CloseOutput( nk, lp, this, r, sd );
 	}
+
+	CometCall makeCometCall( History h ) {
+		if ( close_page.getPopupType() == null ) {
+			Option.trace( "new LocationCometCall <- %s", this );
+			return new LocationCometCall( h, this );
+		}
+		Option.trace( "new CloseCometCall <- %s", this );
+		return new CloseCometCall( h, this );
+	}
 }
 
