@@ -19,7 +19,7 @@ import paraselene.*;
 public class Forward implements Serializable {
 	private static final long serialVersionUID = 212L;
 	private int	error = 0;
-	private URI	redirect_uri = null;
+	private transient URI	redirect_uri = null;
 	PageID	out_page = null;
 
 	private AjaxForward[]	ajax = null;
@@ -27,7 +27,7 @@ public class Forward implements Serializable {
 
 	boolean history_f = true;
 	boolean session_clear_f = false;
-	ArrayList<Cookie>	out_cookie = new ArrayList<Cookie>();
+	transient ArrayList<Cookie>	out_cookie = new ArrayList<Cookie>();
 	boolean done_f = false;
 
 
