@@ -258,7 +258,7 @@ public abstract class PageFactory extends Thread {
 		if ( path.length == 0 )	path = new String[] { uri };
 		path = path[0].split( "\\?" );
 		if ( path.length == 0 )	path = new String[] { uri };
-		path = path[0].split( ";jsessionid=" );
+		path = path[0].split( ";" );
 		if ( path.length == 0 )	path = new String[] { uri };
 		path = path[0].split( "/" );
 		int	list_cnt = alias_list.size();
@@ -295,7 +295,13 @@ public abstract class PageFactory extends Thread {
 		return null;
 	}
 
-	boolean isAlias( String uri ) {
+	/**
+	 * エイリアスURIであるか？
+	 * 指定 URI が何れかのページのエイリアスであれば true を返します。
+	 * @param uri URI。
+	 * @return true:エイリアス、false:エイリアスではない。
+	 */
+	public boolean isAlias( String uri ) {
 		AliasData	ret = getPage( uri );
 		if ( ret == null )	return false;
 		returnPage( ret.page );
