@@ -15,6 +15,7 @@ import paraselene.*;
 public class Popup extends Forward implements AjaxForward {
 	private static final long serialVersionUID = 2L;
 	Page active_page = null;
+	Page view_page = null;
 	/**
 	 * ポップアップ種別。
 	 */
@@ -65,18 +66,42 @@ public class Popup extends Forward implements AjaxForward {
 	private Type type;
 
 	/**
-	 * コンストラクタ。
-	 * @param id 指定ページのポップアップ。
+	 * コンストラクタ。新しいダイアログを表示します。
+	 * @param id 表示するページ。
 	 * @param dialog_type ポップアップ種別。
 	 */
 	public Popup( PageID id, Type dialog_type ) {
 		super( id );
 		type = dialog_type;
-		if ( isModelessAlert( type, SandBox.getCurrentRequestParameter().getHistory(), false ) ) {
+		if ( SandBox.isCurrentDaemon() )	return;
+		initType( SandBox.getCurrentRequestParameter().getHistory() );
+	}
+
+	void initType( History hist ) {
+		if ( isModelessAlert( type, hist, false ) ) {
 			overwriteType( Type.MODAL );
 		}
 	}
 
+	/**
+	 * コンストラクタ。新しいダイアログを表示します。
+	 * または、指定ページの Z順を手前にします。<br>
+	 * 指定pageがダイアログであればアクティブ指示となり、そうでなければ
+	 * 新規ダイアログとしてポップアップ表示します。
+	 * @param page 表示するページ。
+	 * @param dialog_type ポップアップ種別。
+	 */
+	public Popup( Page page, Type dialog_type ) {
+		this( page.getParentPage().getID(), dialog_type );
+		page = page.getParentPage();
+		if ( page.getPopupType() != null ) {
+			active_page = page;
+		}
+		else {
+			view_page = page;
+		}
+	}
+
 	static boolean isModeless( Type mine ) {
 		if ( mine == null )	return false;
 		return !mine.isMode();
@@ -101,13 +126,12 @@ public class Popup extends Forward implements AjaxForward {
 	}
 
 	/**
-	 * コンストラクタ。
-	 * 指定ページの Z順を手前にします。
+	 * コンストラクタ。<br>
+	 * new Popup( page, Popup.Type.MODELESS ) と等価です。
 	 * @param page MODELESSのポップアップ。
 	 */
 	public Popup( Page page ) {
-		this( page.getParentPage().getID(), Type.MODELESS );
-		active_page = page.getParentPage();
+		this( page, Type.MODELESS );
 	}
 
 	Page getPage( Page from ) {
@@ -119,6 +143,10 @@ public class Popup extends Forward implements AjaxForward {
 			Option.trace( "Popup#getPage -> null" );
 			return null;
 		}
+		if ( view_page != null ) {
+			Option.trace( "Popup#getPage -> %s", view_page.getUniqueKey() );
+			return view_page;
+		}
 		Page	p = out_page.getPageFactory().getPage( out_page.getID() );
 		Option.trace( "Popup#getPage -> %s", p.getUniqueKey() );
 		return p;
@@ -153,7 +181,13 @@ public class Popup extends Forward implements AjaxForward {
 		}
 		else {
 			buf = buf.append( "open:" );
-			buf = buf.append( getPageID().toString() );
+			if ( view_page == null ) {
+				buf = buf.append( getPageID().toString() );
+			}
+			else {
+				buf = buf.append( view_page.getID().toString() );
+				buf = buf.append( "/" ).append( view_page.getUniqueKey() );
+			}
 			buf = buf.append( "/" ).append( type.toString() );
 		}
 		return buf.toString();
@@ -163,5 +197,10 @@ public class Popup extends Forward implements AjaxForward {
 		Option.trace( "new OpenOutput <- %s", this );
 		return new OpenOutput( nk, lp, this, getType(), r, sd );
 	}
+
+	CometCall makeCometCall( History h ) {
+		Option.trace( "new OpenCometCall <- %s", this );
+		return new OpenCometCall( h, this, getType() );
+	}
 }
 
