@@ -485,7 +485,7 @@ public class SandBox extends Thread {
 			}
 			catch( Exception e ) {
 				try {
-					e.printStackTrace();
+					//e.printStackTrace();
 					Thread.sleep( 1000 );
 				}
 				catch( Exception ee ) {}
