@@ -8,6 +8,7 @@ package paraselene.supervisor;
 
 
 import paraselene.*;
+import paraselene.ajax.*;
 import java.util.*;
 import java.net.*;
 import java.io.*;
@@ -15,16 +16,39 @@ import javax.servlet.*;
 import javax.servlet.http.*;
 
 
-class DataHolder {
-	Supervisor	sv;
+class DataHolder implements ServerInformation {
+	private HttpServletRequest	req;
+	private boolean search_engine = false;
+	private PageFactory	fact;
+
 	RequestParameter	request;
-	HttpServletRequest	req;
 	HttpServletResponse	response;
 	SessionData	data;
 	boolean	session_null = true;
-	boolean search_engine = false;
 
-	DataHolder( Supervisor s ) { sv = s; }
+	private String	serverName;
+	private String	contextPath;
+
+	DataHolder( Supervisor sv, HttpServletRequest rq ) {
+		req = rq;
+		serverName = req.getServerName();
+		contextPath = req.getContextPath();
+		fact = sv.getPageFactory();
+	}
+	HttpServletRequest getRequest() {
+		return req;
+	}
+	public String getServerName(){ return serverName; }
+	public String getContextPath(){ return contextPath; }
+	public TransactionSequencer getTransactionSequencer() {
+		return data.seq;
+	}
+	public boolean isSearchEngine(){ return search_engine; }
+	void setSearchEngine( boolean flag ) {
+		search_engine = flag;
+	}
+	public HistorySet getHistorySet() { return data.hist; }
+	public PageFactory getPageFactory() { return fact; }
 }
 
 class RedirectData implements Serializable {
@@ -43,92 +67,6 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	private HashMap<PageID, RedirectData>	pending = new HashMap<PageID, RedirectData>();
 	private volatile int client;
 
-/******* CACHE ******
-	private class Waiter implements Serializable {
-		private static final long serialVersionUID = 25L;
-		volatile boolean flag = true;
-	}
-	private static final String	DUMMY = paraselene.tag.form.Form.FORM_DUMMY;
-	private ArrayList<String>	cache_dummy_key = new ArrayList<String>();
-	private ArrayList<CacheAjax>	cache_ajax = new ArrayList<CacheAjax>();
-	private HashMap<String, Waiter>	working_ajax = new HashMap<String, Waiter>();
-	private static final int CACHE_MAX = 5;
-
-	private String getCacheKey( RequestParameter param ) {
-		return param.makeCacheKey();
-	}
-
-	void cacheEntry( RequestParameter param, CacheAjax ca ) {
-		String	key = getCacheKey( param );
-		if ( key == null )	return;
-		synchronized( cache_dummy_key ) {
-			cache_dummy_key.add( key );
-			cache_ajax.add( ca );
-			if ( cache_dummy_key.size() > CACHE_MAX ) {
-				cache_dummy_key.remove( 0 );
-				cache_ajax.remove( 0 );
-			}
-		}
-		cacheUnlock( param );
-	}
-
-	void cacheUnlock( RequestParameter param ) {
-		if ( param == null )	return;
-		String	key = getCacheKey( param );
-		if ( key == null )	return;
-		Waiter	o = null;
-		synchronized( working_ajax ) {
-			o = working_ajax.remove( key );
-		}
-		if ( o == null )	return;
-		synchronized( o ) {
-			o.flag = false;
-			Option.trace( "%s release", key );
-			o.notifyAll();
-		}
-	}
-
-	Forward cacheResponse( RequestParameter param, HttpServletResponse res ) throws IOException {
-		String	key = getCacheKey( param );
-		if ( key == null )	return null;
-		Waiter	o1 = null, o2 = new Waiter();
-		synchronized( working_ajax ) {
-			o1 = working_ajax.get( key );
-			if ( o1 == null ) {
-				Option.trace( "%s ajax lock", key );
-				working_ajax.put( key, o2 );
-			}
-		}
-		if ( o1 != null ) {
-			synchronized( o1 ) {
-				if ( o1.flag ) {
-					Option.trace( "%s waiting", key );
-					while( true ){
-						try {
-							o1.wait();
-							break;
-						}
-						catch( InterruptedException e ){}
-					}
-				}
-			}
-			return cacheResponse( param, res );
-		}
-		synchronized( cache_dummy_key ) {
-			for ( int i = cache_dummy_key.size() - 1; i >= 0; i-- ) {
-				String	ck = cache_dummy_key.get( i );
-				if ( ck.equals( key ) ) {
-					cacheUnlock( param );
-					CacheAjax	ca = cache_ajax.get( i );
-					ca.writeTo( res );
-					Option.trace( "used cache response" );
-					return new NullForward();
-				}
-			}
-		}
-		return null;
-	}
-******************************/
 
 	private String cut( String org, int len ) {
 		if ( org == null )	return null;
@@ -207,21 +145,15 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 				return new Forward( rd.redirect_path, false );
 			}
 		}
-/*
-		int	cnt = list.size();
-		for ( int i = 0; i < cnt; i++ ) {
-			RedirectData	rd = list.get( i );
-			if ( rd.posted.equals( post ) ) {
-				return new Forward( rd.redirect_path, false );
-			}
-		}
-*/
 		return null;
 	}
 
 	public void valueBound( HttpSessionBindingEvent ev ) {}
 	public void valueUnbound( HttpSessionBindingEvent ev ) {
-		if ( !planed_clear )	hist.drop();
+		if ( !planed_clear ) {
+			hist.drop();
+			Ajax.removeComet( ev.getSession().getId() );
+		}
 	}
 	boolean	planed_clear = false;
 }
