@@ -239,14 +239,27 @@ public abstract class Supervisor extends HttpServlet {
 		else {
 			alias_f = holder.getPageFactory().isAlias( uri );
 			if ( alias_f && to_key != HistorySet.ROOT ) {
+				String[]	dev = uri.split( "/" );
 				StringBuilder	buf = new StringBuilder( TransactionSequencer.SELENE[5] );
 				buf = buf.append( "." );
 				buf = buf.append( Integer.toString( to_key, Character.MAX_RADIX ) );
 				buf = buf.append( "." );
 				buf = buf.append( TransactionSequencer.SELENE[6] );
 				buf = buf.append( "." );
-				buf = buf.append( uri );
-				uri = buf.toString();
+				if ( dev.length == 0 ) {
+					buf = buf.append( uri );
+					uri = buf.toString();
+				}
+				else {
+					StringBuilder	p = new StringBuilder();
+					for ( int i = 0; i < dev.length - 1; i++ ) {
+						p = p.append( dev[i] );
+						p = p.append( "/" );
+					}
+					p = p.append( buf );
+					p = p.append( dev[dev.length - 1] );
+					uri = p.toString();
+				}
 			}
 			if ( !alias_f && isMyHost( uri ) && holder instanceof DataHolder ) {
 				uri = ((DataHolder)holder).response.encodeURL( URIValue.encode( uri, enc, xml_f ) );
@@ -265,16 +278,19 @@ public abstract class Supervisor extends HttpServlet {
 	}
 
 	private static boolean isMyHost( DataHolder holder, String uri ) {
-		if ( holder == null || uri == null )	return false;
+		if ( uri == null )	return false;
 		try {
 			URI	test = new URI( URIValue.encode( uri, "utf-8" ) );
-			if ( !test.isAbsolute() )	return true;
+			if ( test.isAbsolute() == false ) {
+				return true;
+			}
 			String	sch = test.getScheme();
 			if ( sch != null ) {
 				if ( !"https".equals( sch ) && !"http".equals( sch ) )	return false;
 			}
 			String	host = test.getHost();
 			if ( host == null )	return true;
+			if ( holder == null )	return false;
 			if ( host.equals( holder.getServerName() ) )	return true;
 		}
 		catch( Exception e ){
@@ -672,6 +688,7 @@ public abstract class Supervisor extends HttpServlet {
 	private void writeWork( Page[] out_ret, boolean session_f, Forward fw, DataHolder holder ) throws Exception {
 		SessionData data = holder.data;
 		HttpServletResponse	res = holder.response;
+		out_ret[1].setResponse( res );
 		Page	next_page = out_ret[0];
 		RequestParameter	param = holder.request;
 		HttpSession	session = param.getSession();
