@@ -89,11 +89,14 @@ public class Anchor extends Tag implements PageHooker, Clickable {
 				}
 				list.add( item[i] );
 			}
-			list.add( new QueryItem( Form.PAGE_UKEY, getAssignedPage().getUniqueKey() ) );
 			if ( !fix_id_f ) {
 				list.add( new QueryItem( ANCHOR_URL_ID, make_id() ) );
 			}
-			list.add( new QueryItem( ANCHOR_ID, makeID() ) );
+			Page	my_page = getAssignedPage();
+			if ( !req.getSupervisor().getPageFactory().isAlias( url ) ) {
+				list.add( new QueryItem( Form.PAGE_UKEY, my_page.getUniqueKey() ) );
+				list.add( new QueryItem( ANCHOR_ID, makeID() ) );
+			}
 			uv.setQuery( list.toArray( new QueryItem[0] ) );
 		}
 	}
