@@ -28,14 +28,13 @@ public class PageBypassedDiv extends Tag implements PageHooker {
 		super( "div", false );
 	}
 
-	/**
-	 * コンストラクタ。
-	 * @param history 履歴。
-	 * @param page バイパスするページ。
-	 */
-	public PageBypassedDiv( History history, Page page ) {
-		this();
-		setBypassPage( history, page );
+	private static void setPageServerInformation( Page p, PageServerInformation psi ) {
+		if ( p == null )	return;
+		PageBypassedDiv[]	pbd = p.getPageBypassedDiv();
+		for ( int i = 0; i < pbd.length; i++ ) {
+			setPageServerInformation( pbd[i].getBypassPage(), psi );
+		}
+		p.setPageServerInformation( psi );
 	}
 
 	/**
@@ -44,12 +43,19 @@ public class PageBypassedDiv extends Tag implements PageHooker {
 	 * @param page バイパスするページ。
 	 */
 	public void setBypassPage( History history, Page page ) {
+		if ( link_page == page )	return;
+		setPageServerInformation( link_page, null );
 		history.removeSatellitePage( link_page );
 		view_page = page;
 		link_page = page;
 		if ( page != null ) {
-			page.setParentPage( getAssignedPage() );
+			Page	ap = getAssignedPage();
+			PageServerInformation	psi = ap.getPageServerInformation();
+			setPageServerInformation( page, psi );
+			page.setParentPage( ap );
 			history.addSatellitePage( page );
+			Tag	tag = page.getMainTag();
+			if ( tag != null )	tag.setModify();
 		}
 	}
 
@@ -58,8 +64,12 @@ public class PageBypassedDiv extends Tag implements PageHooker {
 	}
 
 	public void afterOutput( Page from, Page to, RequestParameter req ) throws Exception {
+		commitDaemon();
+	}
+
+	public void commitDaemon() {
 		if ( view_page == null )	return;
-		to.addOnLoadScript( view_page.getOnLoadScript() );
+		getAssignedPage().addOnLoadScript( view_page.getOnLoadScript() );
 		view_page.resetOnLoadScript();
 	}
 
